@@ -3,15 +3,15 @@
 rm tests.log
 rm dist* -r
 set -e
-#tox -r > tests.log
-#tests_results=$(cat tests.log | grep "congratulations")
-#if ! [[ -z ${tests_results} ]]; then
+tox -r > tests.log
+tests_results=$(cat tests.log | grep "congratulations")
+if ! [[ -z ${tests_results} ]]; then
   git_tag=$1
   sed -i '6s/.*/version = "'${git_tag}'"/' setup.py
   sed -i '1s/.*/__version__ = "'${git_tag}'"/' sherlockpipe/__init__.py
   git add setup.py
   git add sherlockpipe/__init__.py
-  git commit -m "Preparing release ${git_tag}"
+  git commit -m "Preparing releasteste ${git_tag}"
   git tag ${git_tag} -m "New release"
   git push
   git push --tags
@@ -27,7 +27,7 @@ set -e
   echo "Push docker image with tag ${git_tag}"
   sudo docker push sherlockpipe/sherlockpipe:latest
   sudo docker push sherlockpipe/sherlockpipe:${git_tag}
-#else
-#  echo "TESTS FAILED. See tests.log"
-#fi
+else
+  echo "TESTS FAILED. See tests.log"
+fi
 
